==> kubernetes-model-core-6.5.1-sources.jar: io/fabric8/kubernetes/api/model/APIServiceStatusFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class APIServiceStatusFluentImpl<A extends APIServiceStatusFluent<A>> extends BaseFluent<A> implements APIServiceStatusFluent<A>{
  public APIServiceStatusFluentImpl() {
  }
  public APIServiceStatusFluentImpl(APIServiceStatus instance) {
    this.withConditions(instance.getConditions()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private ArrayList<APIServiceConditionBuilder> conditions = new ArrayList<APIServiceConditionBuilder>();
  private Map<String,Object> additionalProperties;
  public A addToConditions(Integer index,APIServiceCondition item) {
    if (this.conditions == null) {this.conditions = new ArrayList<APIServiceConditionBuilder>();}
    APIServiceConditionBuilder builder = new APIServiceConditionBuilder(item);_visitables.get("conditions").add(index >= 0 ? index : _visitables.get("conditions").size(), builder);this.conditions.add(index >= 0 ? index : conditions.size(), builder); return (A)this;
  }
  public A setToConditions(Integer index,APIServiceCondition item) {
    if (this.conditions == null) {this.conditions = new ArrayList<APIServiceConditionBuilder>();}
    APIServiceConditionBuilder builder = new APIServiceConditionBuilder(item);
    if (index < 0 || index >= _visitables.get("conditions").size()) { _visitables.get("conditions").add(builder); } else { _visitables.get("conditions").set(index, builder);}
    if (index < 0 || index >= conditions.size()) { conditions.add(builder); } else { conditions.set(index, builder);}
     return (A)this;
  }
  public A addToConditions(io.fabric8.kubernetes.api.model.APIServiceCondition... items) {
    if (this.conditions == null) {this.conditions = new ArrayList<APIServiceConditionBuilder>();}
    for (APIServiceCondition item : items) {APIServiceConditionBuilder builder = new APIServiceConditionBuilder(item);_visitables.get("conditions").add(builder);this.conditions.add(builder);} return (A)this;
  }
  public A addAllToConditions(Collection<APIServiceCondition> items) {
    if (this.conditions == null) {this.conditions = new ArrayList<APIServiceConditionBuilder>();}
    for (APIServiceCondition item : items) {APIServiceConditionBuilder builder = new APIServiceConditionBuilder(item);_visitables.get("conditions").add(builder);this.conditions.add(builder);} return (A)this;
  }
  public A removeFromConditions(io.fabric8.kubernetes.api.model.APIServiceCondition... items) {
    for (APIServiceCondition item : items) {APIServiceConditionBuilder builder = new APIServiceConditionBuilder(item);_visitables.get("conditions").remove(builder);if (this.conditions != null) {this.conditions.remove(builder);}} return (A)this;
  }
  public A removeAllFromConditions(Collection<APIServiceCondition> items) {
    for (APIServiceCondition item : items) {APIServiceConditionBuilder builder = new APIServiceConditionBuilder(item);_visitables.get("conditions").remove(builder);if (this.conditions != null) {this.conditions.remove(builder);}} return (A)this;
  }
  public A removeMatchingFromConditions(Predicate<APIServiceConditionBuilder> predicate) {
    if (conditions == null) return (A) this;
    final Iterator<APIServiceConditionBuilder> each = conditions.iterator();
    final List visitables = _visitables.get("conditions");
    while (each.hasNext()) {
      APIServiceConditionBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  /**
   * This method has been deprecated, please use method buildConditions instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<APIServiceCondition> getConditions() {
    return conditions != null ? build(conditions) : null;
  }
  public List<APIServiceCondition> buildConditions() {
    return conditions != null ? build(conditions) : null;
  }
  public APIServiceCondition buildCondition(Integer index) {
    return this.conditions.get(index).build();
  }
  public APIServiceCondition buildFirstCondition() {
    return this.conditions.get(0).build();
  }
  public APIServiceCondition buildLastCondition() {
    return this.conditions.get(conditions.size() - 1).build();
  }
  public APIServiceCondition buildMatchingCondition(Predicate<APIServiceConditionBuilder> predicate) {
    for (APIServiceConditionBuilder item: conditions) { if(predicate.test(item)){ return item.build();} } return null;
  }
  public Boolean hasMatchingCondition(Predicate<APIServiceConditionBuilder> predicate) {
    for (APIServiceConditionBuilder item: conditions) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withConditions(List<APIServiceCondition> conditions) {
    if (this.conditions != null) { _visitables.get("conditions").removeAll(this.conditions);}
    if (conditions != null) {this.conditions = new ArrayList(); for (APIServiceCondition item : conditions){this.addToConditions(item);}} else { this.conditions = null;} return (A) this;
  }
  public A withConditions(io.fabric8.kubernetes.api.model.APIServiceCondition... conditions) {
    if (this.conditions != null) {this.conditions.clear();}
    if (conditions != null) {for (APIServiceCondition item :conditions){ this.addToConditions(item);}} return (A) this;
  }
  public Boolean hasConditions() {
    return conditions != null && !conditions.isEmpty();
  }
  public A addNewCondition(String lastTransitionTime,String message,String reason,String status,String type) {
    return (A)addToConditions(new APIServiceCondition(lastTransitionTime, message, reason, status, type));
  }
  public APIServiceStatusFluent.ConditionsNested<A> addNewCondition() {
    return new APIServiceStatusFluentImpl.ConditionsNestedImpl();
  }
  public APIServiceStatusFluent.ConditionsNested<A> addNewConditionLike(APIServiceCondition item) {
    return new APIServiceStatusFluentImpl.ConditionsNestedImpl(-1, item);
  }
  public APIServiceStatusFluent.ConditionsNested<A> setNewConditionLike(Integer index,APIServiceCondition item) {
    return new APIServiceStatusFluentImpl.ConditionsNestedImpl(index, item);
  }
  public APIServiceStatusFluent.ConditionsNested<A> editCondition(Integer index) {
    if (conditions.size() <= index) throw new RuntimeException("Can't edit conditions. Index exceeds size.");
    return setNewConditionLike(index, buildCondition(index));
  }
  public APIServiceStatusFluent.ConditionsNested<A> editFirstCondition() {
    if (conditions.size() == 0) throw new RuntimeException("Can't edit first conditions. The list is empty.");
    return setNewConditionLike(0, buildCondition(0));
  }
  public APIServiceStatusFluent.ConditionsNested<A> editLastCondition() {
    int index = conditions.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last conditions. The list is empty.");
    return setNewConditionLike(index, buildCondition(index));
  }
  public APIServiceStatusFluent.ConditionsNested<A> editMatchingCondition(Predicate<APIServiceConditionBuilder> predicate) {
    int index = -1;
    for (int i=0;i<conditions.size();i++) { 
    if (predicate.test(conditions.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching conditions. No match found.");
    return setNewConditionLike(index, buildCondition(index));
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    APIServiceStatusFluentImpl that = (APIServiceStatusFluentImpl) o;
    if (conditions != null ? !conditions.equals(that.conditions) :that.conditions != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(conditions,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (conditions != null && !conditions.isEmpty()) { sb.append("conditions:"); sb.append(conditions + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class ConditionsNestedImpl<N> extends APIServiceConditionFluentImpl<APIServiceStatusFluent.ConditionsNested<N>> implements APIServiceStatusFluent.ConditionsNested<N>,Nested<N>{
    ConditionsNestedImpl(Integer index,APIServiceCondition item) {
      this.index = index;
      this.builder = new APIServiceConditionBuilder(this, item);
    }
    ConditionsNestedImpl() {
      this.index = -1;
      this.builder = new APIServiceConditionBuilder(this);
    }
    APIServiceConditionBuilder builder;
    Integer index;
    public N and() {
      return (N) APIServiceStatusFluentImpl.this.setToConditions(index,builder.build());
    }
    public N endCondition() {
      return and();
    }
    
  }
  
}

==> kubernetes-model-core-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/APIServiceStatusFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class APIServiceStatusFluentImpl<A extends APIServiceStatusFluent<A>> extends BaseFluent<A> implements APIServiceStatusFluent<A>{
  public APIServiceStatusFluentImpl() {
  }
  public APIServiceStatusFluentImpl(APIServiceStatus instance) {
    if (instance != null) {
      this.withConditions(instance.getConditions());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private ArrayList<APIServiceConditionBuilder> conditions = new ArrayList<APIServiceConditionBuilder>();
  private Map<String,Object> additionalProperties;
  public A addToConditions(int index,APIServiceCondition item) {
    if (this.conditions == null) {this.conditions = new ArrayList<APIServiceConditionBuilder>();}
    APIServiceConditionBuilder builder = new APIServiceConditionBuilder(item);
    if (index < 0 || index >= conditions.size()) { _visitables.get("conditions").add(builder); conditions.add(builder); } else { _visitables.get("conditions").add(index, builder); conditions.add(index, builder);}
    return (A)this;
  }
  public A setToConditions(int index,APIServiceCondition item) {
    if (this.conditions == null) {this.conditions = new ArrayList<APIServiceConditionBuilder>();}
    APIServiceConditionBuilder builder = new APIServiceConditionBuilder(item);
    if (index < 0 || index >= conditions.size()) { _visitables.get("conditions").add(builder); conditions.add(builder); } else { _visitables.get("conditions").set(index, builder); conditions.set(index, builder);}
    return (A)this;
  }
  public A addToConditions(io.fabric8.kubernetes.api.model.APIServiceCondition... items) {
    if (this.conditions == null) {this.conditions = new ArrayList<APIServiceConditionBuilder>();}
    for (APIServiceCondition item : items) {APIServiceConditionBuilder builder = new APIServiceConditionBuilder(item);_visitables.get("conditions").add(builder);this.conditions.add(builder);} return (A)this;
  }
  public A addAllToConditions(Collection<APIServiceCondition> items) {
    if (this.conditions == null) {this.conditions = new ArrayList<APIServiceConditionBuilder>();}
    for (APIServiceCondition item : items) {APIServiceConditionBuilder builder = new APIServiceConditionBuilder(item);_visitables.get("conditions").add(builder);this.conditions.add(builder);} return (A)this;
  }
  public A removeFromConditions(io.fabric8.kubernetes.api.model.APIServiceCondition... items) {
    for (APIServiceCondition item : items) {APIServiceConditionBuilder builder = new APIServiceConditionBuilder(item);_visitables.get("conditions").remove(builder);if (this.conditions != null) {this.conditions.remove(builder);}} return (A)this;
  }
  public A removeAllFromConditions(Collection<APIServiceCondition> items) {
    for (APIServiceCondition item : items) {APIServiceConditionBuilder builder = new APIServiceConditionBuilder(item);_visitables.get("conditions").remove(builder);if (this.conditions != null) {this.conditions.remove(builder);}} return (A)this;
  }
  public A removeMatchingFromConditions(Predicate<APIServiceConditionBuilder> predicate) {
    if (conditions == null) return (A) this;
    final Iterator<APIServiceConditionBuilder> each = conditions.iterator();
    final List visitables = _visitables.get("conditions");
    while (each.hasNext()) {
      APIServiceConditionBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  /**
   * This method has been deprecated, please use method buildConditions instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<APIServiceCondition> getConditions() {
    return conditions != null ? build(conditions) : null;
  }
  public List<APIServiceCondition> buildConditions() {
    return conditions != null ? build(conditions) : null;
  }
  public APIServiceCondition buildCondition(int index) {
    return this.conditions.get(index).build();
  }
  public APIServiceCondition buildFirstCondition() {
    return this.conditions.get(0).build();
  }
  public APIServiceCondition buildLastCondition() {
    return this.conditions.get(conditions.size() - 1).build();
  }
  public APIServiceCondition buildMatchingCondition(Predicate<APIServiceConditionBuilder> predicate) {
    for (APIServiceConditionBuilder item: conditions) { if(predicate.test(item)){ return item.build();} } return null;
  }
  public Boolean hasMatchingCondition(Predicate<APIServiceConditionBuilder> predicate) {
    for (APIServiceConditionBuilder item: conditions) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withConditions(List<APIServiceCondition> conditions) {
    if (this.conditions != null) { _visitables.get("conditions").clear();}
    if (conditions != null) {this.conditions = new ArrayList(); for (APIServiceCondition item : conditions){this.addToConditions(item);}} else { this.conditions = null;} return (A) this;
  }
  public A withConditions(io.fabric8.kubernetes.api.model.APIServiceCondition... conditions) {
    if (this.conditions != null) {this.conditions.clear(); _visitables.remove("conditions"); }
    if (conditions != null) {for (APIServiceCondition item :conditions){ this.addToConditions(item);}} return (A) this;
  }
  public Boolean hasConditions() {
    return conditions != null && !conditions.isEmpty();
  }
  public A addNewCondition(String lastTransitionTime,String message,String reason,String status,String type) {
    return (A)addToConditions(new APIServiceCondition(lastTransitionTime, message, reason, status, type));
  }
  public APIServiceStatusFluentImpl.ConditionsNested<A> addNewCondition() {
    return new APIServiceStatusFluentImpl.ConditionsNestedImpl();
  }
  public APIServiceStatusFluentImpl.ConditionsNested<A> addNewConditionLike(APIServiceCondition item) {
    return new APIServiceStatusFluentImpl.ConditionsNestedImpl(-1, item);
  }
  public APIServiceStatusFluentImpl.ConditionsNested<A> setNewConditionLike(int index,APIServiceCondition item) {
    return new APIServiceStatusFluentImpl.ConditionsNestedImpl(index, item);
  }
  public APIServiceStatusFluentImpl.ConditionsNested<A> editCondition(int index) {
    if (conditions.size() <= index) throw new RuntimeException("Can't edit conditions. Index exceeds size.");
    return setNewConditionLike(index, buildCondition(index));
  }
  public APIServiceStatusFluentImpl.ConditionsNested<A> editFirstCondition() {
    if (conditions.size() == 0) throw new RuntimeException("Can't edit first conditions. The list is empty.");
    return setNewConditionLike(0, buildCondition(0));
  }
  public APIServiceStatusFluentImpl.ConditionsNested<A> editLastCondition() {
    int index = conditions.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last conditions. The list is empty.");
    return setNewConditionLike(index, buildCondition(index));
  }
  public APIServiceStatusFluentImpl.ConditionsNested<A> editMatchingCondition(Predicate<APIServiceConditionBuilder> predicate) {
    int index = -1;
    for (int i=0;i<conditions.size();i++) { 
    if (predicate.test(conditions.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching conditions. No match found.");
    return setNewConditionLike(index, buildCondition(index));
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    APIServiceStatusFluentImpl that = (APIServiceStatusFluentImpl) o;
    if (!java.util.Objects.equals(conditions, that.conditions)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(conditions,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (conditions != null && !conditions.isEmpty()) { sb.append("conditions:"); sb.append(conditions + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class ConditionsNestedImpl<N> extends APIServiceConditionFluentImpl<APIServiceStatusFluentImpl.ConditionsNested<N>> implements APIServiceStatusFluentImpl.ConditionsNested<N>,Nested<N>{
    ConditionsNestedImpl(int index,APIServiceCondition item) {
      this.index = index;
      this.builder = new APIServiceConditionBuilder(this, item);
    }
    ConditionsNestedImpl() {
      this.index = -1;
      this.builder = new APIServiceConditionBuilder(this);
    }
    APIServiceConditionBuilder builder;
    int index;
    public N and() {
      return (N) APIServiceStatusFluentImpl.this.setToConditions(index,builder.build());
    }
    public N endCondition() {
      return and();
    }
    
  }
  
}
